Employee Example
===============================================================================

:download:`employee_view.enaml <../../../examples/employee/employee_view.enaml>`

.. literalinclude:: ../../../examples/employee/employee_view.enaml
    :language: python

:download:`employee.py <../../../examples/employee/employee.py>`

.. literalinclude:: ../../../examples/employee/employee.py
    :language: python

:download:`phone_converter.py <../../../examples/employee/phone_converter.py>`

.. literalinclude:: ../../../examples/employee/phone_converter.py
    :language: python

::

 $ python employee.py

.. image:: images/employee.png
